@@ -200,10 +200,14 @@ impl Window {
 
     // Rest attributes
     window.set_title(&attributes.title);
-    if let Some(Fullscreen::Borderless(Some(f))) = &attributes.fullscreen {
-      let number = f.inner.number;
-      let screen = window.display().default_screen();
-      window.fullscreen_on_monitor(&screen, number);
+    if let Some(Fullscreen::Borderless(m)) = &attributes.fullscreen {
+      if let Some(monitor) = m {
+        let number = monitor.inner.number;
+        let screen = window.display().default_screen();
+        window.fullscreen_on_monitor(&screen, number);
+      } else {
+        window.fullscreen();
+      }
     }
     if attributes.maximized {
       window.maximize();
@@ -664,6 +668,7 @@ pub enum WindowRequest {
   Redraw,
   Menu((Option<MenuItem>, Option<MenuId>)),
   SetMenu((Option<menu::Menu>, AccelGroup, gtk::MenuBar)),
+  GlobalHotKey(u16),
 }
 
 pub fn hit_test(window: &gdk::Window, cx: f64, cy: f64) -> WindowEdge {
