@@ -674,7 +674,7 @@ impl UnownedWindow {
 
     // Roll back temp styles
     if needs_temp_mask {
-      self.set_style_mask_async(curr_mask);
+      self.set_style_mask_sync(curr_mask);
     }
 
     is_zoomed != NO
@@ -752,11 +752,6 @@ impl UnownedWindow {
     shared_state_lock.fullscreen.clone()
   }
 
-  #[inline]
-  pub fn is_maximized(&self) -> bool {
-    self.is_zoomed()
-  }
-
   #[inline]
   pub fn is_visible(&self) -> bool {
     let is_visible: BOOL = unsafe { msg_send![*self.ns_window, isVisible] };
